==> nomachine-8.13.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXTranslator.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXTranslator;no warnings;(my (%__translation)=());sub init{(my $language
=shift (@_));if (__isGerman ($language)){main::nxrequire (((
"\x43\x6f\x6d\x6d\x6f\x6e".$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x47\x65\x72\x6d\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXGermanMessages::getGermanTranslations ());}elsif (
__isSpanish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x53\x70\x61\x6e\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXSpanishMessages::getSpanishTranslations ());}elsif (
__isFrench ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x46\x72\x65\x6e\x63\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXFrenchMessages::getFrenchTranslations ());}elsif (
__isItalian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x49\x74\x61\x6c\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXItalianMessages::getItalianTranslations ());}elsif (
__isPolish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x6c\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXPolishMessages::getPolishTranslations ());}elsif (
__isPortuguese ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x72\x74\x75\x67\x75\x65\x73\x65\x4d\x65\x73\x73\x61\x67\x65\x73"
));((%__translation)=Common::NXPortugueseMessages::getPortugueseTranslations ())
;}elsif (__isRussian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x52\x75\x73\x73\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXRussianMessages::getRussianTranslations ());}(
$Common::NXTranslator::language=$language);}sub translate{(my $message=shift (@_
));(my $result=shift (@_));(my $translation=$__translation{$message});if ((not (
defined ($translation)))){Logger::debug3 (((
"\x4d\x65\x73\x73\x61\x67\x65\x20\x27".$message).
"\x27\x20\x69\x73\x20\x6e\x6f\x74\x20\x74\x72\x61\x6e\x73\x6c\x61\x74\x65\x64\x2e"
));return ((0x1090+ 542-0x12ae));}($$result=$translation);Logger::debug3 (((((
"\x54\x72\x61\x6e\x73\x6c\x61\x74\x65\x64\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x27"
.$message)."\x27\x20\x74\x6f\x20\x27").$translation)."\x27\x2e"));return (
(0x0570+ 3925-0x14c4));}sub getLanguage{if (($language ne (""))){return (
$language);}else{return (undef);}}sub __isGerman{(my $language=shift (@_));if ((
$language eq "\x64\x65\x5f\x44\x45")){return ((0x0a32+ 5504-0x1fb1));}return (
(0x0551+ 1649-0x0bc2));}sub __isSpanish{(my $language=shift (@_));if (($language
 eq "\x65\x73\x5f\x45\x53")){return ((0x0518+ 2792-0x0fff));}return (
(0x0d19+ 3436-0x1a85));}sub __isFrench{(my $language=shift (@_));if (($language 
eq "\x66\x72\x5f\x46\x52")){return ((0x06f1+ 7969-0x2611));}return (
(0x0e3a+ 6276-0x26be));}sub __isItalian{(my $language=shift (@_));if (($language
 eq "\x69\x74\x5f\x49\x54")){return ((0x0198+ 771-0x049a));}return (
(0x18d5+ 1508-0x1eb9));}sub __isPolish{(my $language=shift (@_));if (($language 
eq "\x70\x6c\x5f\x50\x4c")){return ((0x02a5+ 6798-0x1d32));}return (
(0x07da+ 1998-0x0fa8));}sub __isPortuguese{(my $language=shift (@_));if ((
$language eq "\x70\x74\x5f\x50\x54")){return ((0x0f37+ 1336-0x146e));}return (
(0x0954+ 2208-0x11f4));}sub __isRussian{(my $language=shift (@_));if (($language
 eq "\x72\x75\x5f\x52\x55")){return ((0x1363+ 4706-0x25c4));}return (
(0x240d+  82-0x245f));}sub __isEnglish{(my $language=shift (@_));if (($language 
eq "\x65\x6e\x5f\x55\x53")){return ((0x00ac+ 6855-0x1b72));}return (
(0x0191+ 4933-0x14d6));}sub translateTimestampForDateBaseOnLanguage{(my $timestamp
=shift (@_));(my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=
Common::NXTime::getLocalTimeFromTimestamp ($timestamp));($year+=
(0x0ae8+ 608-0x05dc));(++$mon);my ($date);if (__isEnglish (getLanguage ())){
return (((((((((sprintf ("\x25\x30\x32\x64",$mon)."\x2f").sprintf (
"\x25\x30\x32\x64",$mday))."\x2f").$year)."\x2c\x20").sprintf (
"\x25\x30\x32\x64",$hour))."\x3a").sprintf ("\x25\x30\x32\x64",$min)));}else{
return (((((((((sprintf ("\x25\x30\x32\x64",$mday)."\x2f").sprintf (
"\x25\x30\x32\x64",$mon))."\x2f").$year)."\x2c\x20").sprintf ("\x25\x30\x32\x64"
,$hour))."\x3a").sprintf ("\x25\x30\x32\x64",$min)));}}return (
(0x0404+ 8544-0x2563));

==> nomachine-8.14.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXTranslator.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXTranslator;no warnings;(my (%__translation)=());sub init{(my $language
=shift (@_));if (__isGerman ($language)){main::nxrequire (((
"\x43\x6f\x6d\x6d\x6f\x6e".$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x47\x65\x72\x6d\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXGermanMessages::getGermanTranslations ());}elsif (
__isSpanish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x53\x70\x61\x6e\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXSpanishMessages::getSpanishTranslations ());}elsif (
__isFrench ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x46\x72\x65\x6e\x63\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXFrenchMessages::getFrenchTranslations ());}elsif (
__isItalian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x49\x74\x61\x6c\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXItalianMessages::getItalianTranslations ());}elsif (
__isPolish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x6c\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXPolishMessages::getPolishTranslations ());}elsif (
__isPortuguese ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x72\x74\x75\x67\x75\x65\x73\x65\x4d\x65\x73\x73\x61\x67\x65\x73"
));((%__translation)=Common::NXPortugueseMessages::getPortugueseTranslations ())
;}elsif (__isRussian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x52\x75\x73\x73\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXRussianMessages::getRussianTranslations ());}(
$Common::NXTranslator::language=$language);}sub translate{(my $message=shift (@_
));(my $result=shift (@_));(my $translation=$__translation{$message});if ((not (
defined ($translation)))){Logger::debug3 (((
"\x4d\x65\x73\x73\x61\x67\x65\x20\x27".$message).
"\x27\x20\x69\x73\x20\x6e\x6f\x74\x20\x74\x72\x61\x6e\x73\x6c\x61\x74\x65\x64\x2e"
));return ((0x0ffd+ 2876-0x1b39));}($$result=$translation);Logger::debug3 (((((
"\x54\x72\x61\x6e\x73\x6c\x61\x74\x65\x64\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x27"
.$message)."\x27\x20\x74\x6f\x20\x27").$translation)."\x27\x2e"));return (
(0x06b4+ 4534-0x1869));}sub getLanguage{if (($language ne (""))){return (
$language);}else{return (undef);}}sub __isGerman{(my $language=shift (@_));if ((
$language eq "\x64\x65\x5f\x44\x45")){return ((0x0dc1+ 4044-0x1d8c));}return (
(0x06e3+ 3888-0x1613));}sub __isSpanish{(my $language=shift (@_));if (($language
 eq "\x65\x73\x5f\x45\x53")){return ((0x18e4+ 157-0x1980));}return (
(0x1047+ 3715-0x1eca));}sub __isFrench{(my $language=shift (@_));if (($language 
eq "\x66\x72\x5f\x46\x52")){return ((0x204d+ 626-0x22be));}return (
(0x2261+ 683-0x250c));}sub __isItalian{(my $language=shift (@_));if (($language 
eq "\x69\x74\x5f\x49\x54")){return ((0x0598+ 3714-0x1419));}return (
(0x2440+ 163-0x24e3));}sub __isPolish{(my $language=shift (@_));if (($language 
eq "\x70\x6c\x5f\x50\x4c")){return ((0x09ed+   7-0x09f3));}return (
(0x0970+ 1725-0x102d));}sub __isPortuguese{(my $language=shift (@_));if ((
$language eq "\x70\x74\x5f\x50\x54")){return ((0x0e1d+ 4391-0x1f43));}return (
(0x1351+ 3521-0x2112));}sub __isRussian{(my $language=shift (@_));if (($language
 eq "\x72\x75\x5f\x52\x55")){return ((0x0849+ 1462-0x0dfe));}return (
(0x10b6+ 831-0x13f5));}sub __isEnglish{(my $language=shift (@_));if (($language 
eq "\x65\x6e\x5f\x55\x53")){return ((0x0810+ 7639-0x25e6));}return (
(0x0089+ 1640-0x06f1));}sub translateTimestampForDateBaseOnLanguage{(my $timestamp
=shift (@_));(my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=
Common::NXTime::getLocalTimeFromTimestamp ($timestamp));($year+=
(0x1824+ 5591-0x268f));(++$mon);my ($date);if (__isEnglish (getLanguage ())){
return (((((((((sprintf ("\x25\x30\x32\x64",$mon)."\x2f").sprintf (
"\x25\x30\x32\x64",$mday))."\x2f").$year)."\x2c\x20").sprintf (
"\x25\x30\x32\x64",$hour))."\x3a").sprintf ("\x25\x30\x32\x64",$min)));}else{
return (((((((((sprintf ("\x25\x30\x32\x64",$mday)."\x2f").sprintf (
"\x25\x30\x32\x64",$mon))."\x2f").$year)."\x2c\x20").sprintf ("\x25\x30\x32\x64"
,$hour))."\x3a").sprintf ("\x25\x30\x32\x64",$min)));}}return (
(0x0289+ 8313-0x2301));
